# -*- coding: utf-8 -*-
from .tasks import *  # noqa: F401, F403


class IOCheckerError(Exception):
    pass
